# Webinar in June 2022

## Installation and configuration

Installation and configurations instructions are already describe [in here](../README.md)

## Use-Cases for Prisma Cloud CLI


### Query Prisma Cloud


#### Search for LOG4J vulnerability

```
pc stats vulnerabilities --cve CVE-2021-44228
pc -o json stats vulnerabilities --cve CVE-2021-44228 | jq
```

#### Search for LOG4J vulnerability with --config

```
pc --config selfhosted stats vulnerabilities --cve CVE-2021-44228
pc --config selfhosted -o json stats vulnerabilities --cve CVE-2021-44228 | jq
```

#### Get and watch latest logins
```
watch pc --columns username,sourceIP,time,type,status logs audit -h 1 -t login
```

#### Get a list of discovery scan results
```
pc --columns credentialId,provider,serviceType,defended,total,err discovery
```


#### Get latest alerts
```
pc --columns ^id$,alertTime,policy.policyType,resource.name,resource.data.tagSets,policy.name,policy.description alert list --unit minute --amount 30
```

#### Execute RQL and fetch results
```
export RQL="config from cloud.resource where cloud.type = 'aws' AND cloud.region NOT IN ( 'AWS Ireland' , 'AWS Frankfurt' , 'AWS London' ) AND cloud.service = 'Amazon EC2' AND resource.status = Active AND api.name = 'aws-ec2-describe-instances' AND json.rule = state.name equals running"
pc -o json rql --query $RQL --amount 1 --unit day|jq
```

### Filtering

```
pc --config local -o html --columns entityInfo.repoTag.registry,entityInfo.repoTag.repo,entityInfo.repoTag.tag,entityInfo.vulnerabilitiesCount,entityInfo.vulnerabilityDistribution.critical,entityInfo.vulnerabilityDistribution.high,entityInfo.vulnerabilityDistribution.medium scans -l 20 -s nginx  > /tmp/results.html
```

### Bulk edit policies

#### See the command options

```
pc policy set --help
```

#### Enable CSPM policies with Prisma Cloud CLI

```
pc -vv policy set --status enable --compliance_standard 'CIS v1.4.0 (AWS)'
```

#### Disable CSPM policies with Prisma Cloud CLI

```
pc -vv policy set --status disable --compliance_standard 'CIS v1.4.0 (AWS)'
```

#### Disable all policies and enable only certain compliance framework

```
pc -vv policy set --status disable --all_policies
pc -vv policy set --status enable --compliance_standard 'CIS v1.4.0 (AWS)'
pc -vv policy set --status enable --compliance_standard 'ISO 27001:2013' 
pc -vv policy set --status enable --compliance_standard 'GDPR'
pc -vv policy set --status enable --compliance_standard 'SOC 2'
pc -vv policy set --status enable --compliance_standard 'AWS Well-Architected Framework'
```
